@@ -40,6 +40,8 @@ private Q_SLOTS:
     void put();
     void storedPut();
     void storedPutIODevice();
+    void storedPutIODeviceFile();
+    void storedPutIODeviceTempFile();
     void storedPutIODeviceSlowDevice();
     void copyFileToSamePartition();
     void copyDirectoryToSamePartition();
@@ -49,6 +51,9 @@ private Q_SLOTS:
     void copyRelativeSymlinkToSamePartition();
     void copyAbsoluteSymlinkToOtherPartition();
     void copyFolderWithUnaccessibleSubfolder();
+    void copyDataUrl();
+    void suspendFileCopy();
+    void suspendCopy();
     void listRecursive();
     void listFile();
     void killJob();
@@ -73,6 +78,9 @@ private Q_SLOTS:
     void rmdirEmpty();
     void rmdirNotEmpty();
     void stat();
+#ifndef Q_OS_WIN
+    void statSymlink();
+#endif
     void mostLocalUrl();
     void chmodFile();
     void chmodFileError();
@@ -85,6 +93,13 @@ private Q_SLOTS:
 
     void moveAndOverwrite();
     void moveOverSymlinkToSelf();
+    void createSymlink();
+    void createSymlinkTargetDirDoesntExist();
+    void createSymlinkAsShouldSucceed();
+    void createSymlinkAsShouldFailDirectoryExists();
+    void createSymlinkAsShouldFailFileExists();
+    void createSymlinkWithOverwriteShouldWork();
+    void createBrokenSymlink();
 
     // Remote tests
     //void copyFileToSystem();
