@@ -34,6 +34,8 @@ class KUrlComboBox;
 class QMouseEvent;
 
 /**
+ * @class KUrlNavigator kurlnavigator.h <KUrlNavigator>
+ *
  * @brief Widget that allows to navigate through the paths of an URL.
  *
  * The URL navigator offers two modes:
@@ -78,7 +80,7 @@ class KIOFILEWIDGETS_EXPORT KUrlNavigator : public QWidget
 
 public:
     /** @since 4.5 */
-    KUrlNavigator(QWidget *parent = 0);
+    KUrlNavigator(QWidget *parent = nullptr);
 
     /**
      * @param placesModel    Model for the places which are selectable inside a
@@ -426,25 +428,25 @@ protected:
      * to the breadcrumb view.
      * @see QWidget::keyPressEvent()
      */
-    virtual void keyPressEvent(QKeyEvent *event);
+    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
 
     /**
      * Reimplemented for internal purposes.
      */
-    virtual void keyReleaseEvent(QKeyEvent *event);
+    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
 
     /**
      * Paste the clipboard content as URL, if the middle mouse
      * button has been clicked.
      * @see QWidget::mouseReleaseEvent()
      */
-    virtual void mouseReleaseEvent(QMouseEvent *event);
+    void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
 
-    virtual void resizeEvent(QResizeEvent *event);
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
-    virtual void wheelEvent(QWheelEvent *event);
+    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
 
-    virtual bool eventFilter(QObject *watched, QEvent *event);
+    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 #endif
 
 private:
