@@ -59,7 +59,7 @@ struct CookieProp
 CookieListViewItem::CookieListViewItem(QTreeWidget *parent, const QString &dom)
                    :QTreeWidgetItem(parent)
 {
-    init( 0, dom );
+    init( nullptr, dom );
 }
 
 CookieListViewItem::CookieListViewItem(QTreeWidgetItem *parent, CookieProp *cookie)
@@ -102,7 +102,7 @@ void CookieListViewItem::init( CookieProp* cookie, const QString &domain,
 CookieProp* CookieListViewItem::leaveCookie()
 {
     CookieProp *ret = mCookie;
-    mCookie = 0;
+    mCookie = nullptr;
     return ret;
 }
 
@@ -131,7 +131,7 @@ void KCookiesManagement::save()
   // If delete all cookies was requested!
   if(mDeleteAllFlag)
   {
-    QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
+    QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
     QDBusReply<void> reply = kded.call( QStringLiteral("deleteAllCookies") );
     if (!reply.isValid())
     {
@@ -147,7 +147,7 @@ void KCookiesManagement::save()
   QMutableStringListIterator it (mDeletedDomains);
   while (it.hasNext())
   {    
-    QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
+    QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
     QDBusReply<void> reply = kded.call( QStringLiteral("deleteCookiesFromDomain"),( it.next() ) );
     if (!reply.isValid())
     {
@@ -168,7 +168,7 @@ void KCookiesManagement::save()
     CookiePropList list = cookiesDom.value();
     foreach(CookieProp *cookie, list)
     {
-      QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
+      QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
       QDBusReply<void> reply = kded.call( QStringLiteral("deleteCookie"), cookie->domain,
                                           cookie->host, cookie->path,
                                           cookie->name );
@@ -228,7 +228,7 @@ QString KCookiesManagement::quickHelp() const
 
 void KCookiesManagement::on_reloadButton_clicked()
 {
-  QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
+  QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
   QDBusReply<QStringList> reply = kded.call( QStringLiteral("findDomains") );
 
   if (!reply.isValid())
@@ -273,7 +273,7 @@ void KCookiesManagement::on_cookiesTreeWidget_itemExpanded(QTreeWidgetItem *item
   fields << 0 << 1 << 2 << 3;  
   // Always check for cookies in both "foo.bar" and ".foo.bar" domains...
   const QString domain = cookieDom->domain() + QLatin1String(" .") + cookieDom->domain();
-  QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
+  QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
   QDBusReply<QStringList> reply = kded.call(QStringLiteral("findCookies"), QVariant::fromValue(fields),
                                             domain, QString(), QString(), QString());
   if (reply.isValid())
@@ -303,7 +303,7 @@ bool KCookiesManagement::cookieDetails(CookieProp *cookie)
   QList<int> fields;
   fields << 4 << 5 << 7;
 
-  QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
+  QDBusInterface kded(QStringLiteral("org.kde.kcookiejar5"), QStringLiteral("/modules/kcookiejar"), QStringLiteral("org.kde.KCookieServer"), QDBusConnection::sessionBus());
   QDBusReply<QStringList> reply = kded.call( QStringLiteral("findCookies"),
                                              QVariant::fromValue( fields ),
                                              cookie->domain,
@@ -342,7 +342,7 @@ void KCookiesManagement::on_cookiesTreeWidget_currentItemChanged(QTreeWidgetItem
 {
   if (item) {
     CookieListViewItem* cookieItem = static_cast<CookieListViewItem*>(item);
-    CookieProp *cookie = (cookieItem ? cookieItem->cookie() : 0);
+    CookieProp *cookie = cookieItem->cookie();
 
     if (cookie) {
       if (cookie->allLoaded || cookieDetails(cookie)) {
@@ -359,15 +359,17 @@ void KCookiesManagement::on_cookiesTreeWidget_currentItemChanged(QTreeWidgetItem
       clearCookieDetails();
       mUi.configPolicyButton->setEnabled(true);
     }
-
-    mUi.deleteButton->setEnabled(true);
+  } else {
+      mUi.configPolicyButton->setEnabled(false);
   }
+  mUi.deleteButton->setEnabled(item != nullptr);
 }
 
 void KCookiesManagement::on_configPolicyButton_clicked()
 {
   // Get current item
   CookieListViewItem *item = static_cast<CookieListViewItem*>(mUi.cookiesTreeWidget->currentItem());
+  Q_ASSERT(item); // the button is disabled otherwise
 
   if (item)
   {
@@ -387,9 +389,9 @@ void KCookiesManagement::on_configPolicyButton_clicked()
 void KCookiesManagement::on_deleteButton_clicked()
 {
   QTreeWidgetItem* currentItem = mUi.cookiesTreeWidget->currentItem();
+  Q_ASSERT(currentItem); // the button is disabled otherwise
   CookieListViewItem *item = static_cast<CookieListViewItem*>( currentItem );
-  if (item && item->cookie())
-  {
+  if (item->cookie()) {
     CookieListViewItem *parent = static_cast<CookieListViewItem*>(item->parent());
     CookiePropList list = mDeletedCookies.value(parent->domain());
     list.append(item->leaveCookie());
@@ -408,12 +410,10 @@ void KCookiesManagement::on_deleteButton_clicked()
   if (currentItem)
   {
     mUi.cookiesTreeWidget->setCurrentItem( currentItem );
-    //on_cookiesTreeWidget_currentItemChanged( currentItem );
   }
   else
     clearCookieDetails();
 
-  mUi.deleteButton->setEnabled(mUi.cookiesTreeWidget->currentItem());
   mUi.deleteAllButton->setEnabled(mUi.cookiesTreeWidget->topLevelItemCount() > 0);
 
   emit changed( true );
