@@ -23,6 +23,7 @@
 
 #include "kopenwithdialog.h"
 #include "kopenwithdialog_p.h"
+#include "kio_widgets_debug.h"
 
 #include <QDialogButtonBox>
 #include <QtCore/QtAlgorithms>
@@ -69,7 +70,7 @@ class AppNode
 {
 public:
     AppNode()
-        : isDir(false), parent(0), fetched(false)
+        : isDir(false), parent(nullptr), fetched(false)
     {
     }
     ~AppNode()
@@ -167,7 +168,7 @@ void KApplicationModelPrivate::fillNode(const QString &_entryPath, KDEPrivate::A
             entryPath = serviceGroup->entryPath();
             isDir = true;
         } else {
-            qWarning() << "KServiceGroup: Unexpected object in list!";
+            qCWarning(KIO_WIDGETS) << "KServiceGroup: Unexpected object in list!";
             continue;
         }
 
@@ -355,7 +356,7 @@ class KApplicationViewPrivate
 {
 public:
     KApplicationViewPrivate()
-        : appModel(0)
+        : appModel(nullptr)
     {
     }
 
@@ -496,7 +497,7 @@ KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, QWidget *parent)
     if (_urls.count() == 1) {
         text = i18n("<qt>Select the program that should be used to open <b>%1</b>. "
                     "If the program is not listed, enter the name or click "
-                    "the browse button.</qt>",  _urls.first().fileName());
+                    "the browse button.</qt>",  _urls.first().fileName().toHtmlEscaped());
     } else
         // Should never happen ??
     {
@@ -516,7 +517,7 @@ KOpenWithDialog::KOpenWithDialog(const QList<QUrl> &_urls, const QString &_text,
     if (text.isEmpty() && !_urls.isEmpty()) {
         if (_urls.count() == 1) {
             const QString fileName = KStringHandler::csqueeze(_urls.first().fileName());
-            text = i18n("<qt>Select the program you want to use to open the file<br/>%1</qt>", fileName);
+            text = i18n("<qt>Select the program you want to use to open the file<br/>%1</qt>", fileName.toHtmlEscaped());
         } else {
             text = i18np("<qt>Select the program you want to use to open the file.</qt>",
                          "<qt>Select the program you want to use to open the %1 files.</qt>", _urls.count());
@@ -579,9 +580,9 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
 {
     bool bReadOnly = !KAuthorized::authorize(QStringLiteral("shell_access"));
     m_terminaldirty = false;
-    view = 0;
-    m_pService = 0;
-    curService = 0;
+    view = nullptr;
+    m_pService = nullptr;
+    curService = nullptr;
 
     QBoxLayout *topLayout = new QVBoxLayout;
     q->setLayout(topLayout);
@@ -687,7 +688,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
         //    remember->setChecked(true);
         topLayout->addWidget(remember);
     } else {
-        remember = 0L;
+        remember = nullptr;
     }
 
     buttonBox = new QDialogButtonBox(q);
@@ -730,7 +731,7 @@ void KOpenWithDialog::slotHighlighted(const QString &entryPath, const QString &)
         // ### indicate that default value was restored
         d->terminal->setChecked(d->curService->terminal());
         QString terminalOptions = d->curService->terminalOptions();
-        d->nocloseonexit->setChecked((terminalOptions.contains(QLatin1String("--noclose")) > 0));
+        d->nocloseonexit->setChecked((terminalOptions.contains(QLatin1String("--noclose"))));
         d->m_terminaldirty = false; // slotTerminalToggled changed it
     }
 }
@@ -740,7 +741,7 @@ void KOpenWithDialog::slotHighlighted(const QString &entryPath, const QString &)
 void KOpenWithDialog::slotTextChanged()
 {
     // Forget about the service
-    d->curService = 0L;
+    d->curService = nullptr;
     d->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!d->edit->text().isEmpty());
 }
 
@@ -905,7 +906,7 @@ bool KOpenWithDialogPrivate::checkAccept()
         // qDebug() << "Setting m_command to" << m_command;
     }
     if (m_pService && terminal->isChecked() != m_pService->terminal()) {
-        m_pService = 0;    // It's not exactly this service we're running
+        m_pService = nullptr;    // It's not exactly this service we're running
     }
 
     const bool bRemember = remember && remember->isChecked();
