@@ -18,6 +18,7 @@
 */
 
 #include "kurlrequester.h"
+#include "kio_widgets_debug.h"
 
 #include <kcombobox.h>
 #include <kdragwidgetdecorator.h>
@@ -64,7 +65,7 @@ private:
         QDrag *dragObject() Q_DECL_OVERRIDE
         {
             if (m_button->m_urls.isEmpty()) {
-                return 0;
+                return nullptr;
             }
 
             QDrag *drag = new QDrag(m_button);
@@ -86,9 +87,10 @@ class KUrlRequester::KUrlRequesterPrivate
 public:
     KUrlRequesterPrivate(KUrlRequester *parent)
         : m_parent(parent),
-          edit(0),
-          combo(0),
-          fileDialogMode(KFile::File | KFile::ExistingOnly | KFile::LocalOnly)
+          edit(nullptr),
+          combo(nullptr),
+          fileDialogMode(KFile::File | KFile::ExistingOnly | KFile::LocalOnly),
+          fileDialogAcceptMode(QFileDialog::AcceptOpen)
     {
     }
 
@@ -119,26 +121,25 @@ public:
         }
     }
 
-    void connectSignals(QObject *receiver)
+    void connectSignals(KUrlRequester *receiver)
     {
-        QObject *sender;
+        QLineEdit *sender;
         if (combo) {
-            sender = combo;
+            sender = combo->lineEdit();
         } else {
             sender = edit;
         }
+        if (sender) {
+            connect(sender, &QLineEdit::textChanged,
+                    receiver, &KUrlRequester::textChanged);
+            connect(sender, &QLineEdit::textEdited,
+                    receiver, &KUrlRequester::textEdited);
 
-        if (combo)
-            connect(sender, SIGNAL(editTextChanged(QString)),
-                    receiver, SIGNAL(textChanged(QString)));
-        else
-            connect(sender, SIGNAL(textChanged(QString)),
-                    receiver, SIGNAL(textChanged(QString)));
-
-        connect(sender, SIGNAL(returnPressed()),
-                receiver, SIGNAL(returnPressed()));
-        connect(sender, SIGNAL(returnPressed(QString)),
-                receiver, SIGNAL(returnPressed(QString)));
+            connect(sender, SIGNAL(returnPressed()),
+                    receiver, SIGNAL(returnPressed()));
+            connect(sender, SIGNAL(returnPressed(QString)),
+                    receiver, SIGNAL(returnPressed(QString)));
+        }
     }
 
     void setCompletionObject(KCompletion *comp)
@@ -195,7 +196,7 @@ public:
         }
     }
 
-    void applyFileMode(QFileDialog *dlg, KFile::Modes m)
+    static void applyFileMode(QFileDialog *dlg, KFile::Modes m, QFileDialog::AcceptMode acceptMode)
     {
         QFileDialog::FileMode fileMode;
         if (m & KFile::Directory) {
@@ -215,6 +216,7 @@ public:
         }
 
         dlg->setFileMode(fileMode);
+        dlg->setAcceptMode(acceptMode);
     }
 
     // Converts from "*.foo *.bar|Comment" to "Comment (*.foo *.bar)"
@@ -232,20 +234,9 @@ public:
         return qFilters;
     }
 
-    //QFileDialog::getExistingDirectoryUrl only works with local for any version before
-    //5.4, so we have to check our own
     QUrl getDirFromFileDialog(const QUrl &openUrl) const
     {
-
-#if (QT_VERSION <= QT_VERSION_CHECK(5, 4, 0))
-        QFileDialog* dialog = new QFileDialog(m_parent);
-        dialog->setDirectoryUrl(openUrl);
-        dialog->setOptions(QFileDialog::ShowDirsOnly);
-        dialog->exec();
-        return dialog->selectedUrls().first();
-#else
         return QFileDialog::getExistingDirectoryUrl(m_parent, QString(), openUrl, QFileDialog::ShowDirsOnly);
-#endif
     }
 
     // slots
@@ -259,7 +250,9 @@ public:
     KLineEdit *edit;
     KComboBox *combo;
     KFile::Modes fileDialogMode;
+    QFileDialog::AcceptMode fileDialogAcceptMode;
     QString fileDialogFilter;
+    QStringList mimeTypeFilters;
     KEditListWidget::CustomEditor editor;
     KUrlDragPushButton *myButton;
     QFileDialog *myFileDialog;
@@ -301,7 +294,7 @@ KUrlRequester::~KUrlRequester()
 
 void KUrlRequester::KUrlRequesterPrivate::init()
 {
-    myFileDialog = 0L;
+    myFileDialog = nullptr;
     fileDialogModality = Qt::ApplicationModal;
 
     if (!combo && !edit) {
@@ -322,7 +315,7 @@ void KUrlRequester::KUrlRequesterPrivate::init()
     myButton->setFixedSize(buttonSize, buttonSize);
     myButton->setToolTip(i18n("Open file dialog"));
 
-    m_parent->connect(myButton, SIGNAL(pressed()), SLOT(_k_slotUpdateUrl()));
+    connect(myButton, SIGNAL(pressed()), m_parent, SLOT(_k_slotUpdateUrl()));
 
     widget->installEventFilter(m_parent);
     m_parent->setFocusProxy(widget);
@@ -330,7 +323,7 @@ void KUrlRequester::KUrlRequesterPrivate::init()
     topLayout->addWidget(myButton);
 
     connectSignals(m_parent);
-    m_parent->connect(myButton, SIGNAL(clicked()), m_parent, SLOT(_k_slotOpenDialog()));
+    connect(myButton, SIGNAL(clicked()), m_parent, SLOT(_k_slotOpenDialog()));
 
     m_startDir = QUrl::fromLocalFile(QDir::currentPath());
     m_startDirCustomized = false;
@@ -440,6 +433,8 @@ void KUrlRequester::KUrlRequesterPrivate::_k_slotOpenDialog()
             dlg->setDirectoryUrl(m_startDir);
         }
 
+        dlg->setAcceptMode(fileDialogAcceptMode);
+
         //Update the file dialog window modality
         if (dlg->windowModality() != fileDialogModality) {
             dlg->setWindowModality(fileDialogModality);
@@ -480,7 +475,7 @@ void KUrlRequester::setMode(KFile::Modes mode)
     }
 
     if (d->myFileDialog) {
-        d->applyFileMode(d->myFileDialog, mode);
+        d->applyFileMode(d->myFileDialog, mode, d->fileDialogAcceptMode);
     }
 }
 
@@ -489,6 +484,20 @@ KFile::Modes KUrlRequester::mode() const
     return d->fileDialogMode;
 }
 
+void KUrlRequester::setAcceptMode(QFileDialog::AcceptMode mode)
+{
+    d->fileDialogAcceptMode = mode;
+
+    if (d->myFileDialog) {
+        d->applyFileMode(d->myFileDialog, d->fileDialogMode, mode);
+    }
+}
+
+QFileDialog::AcceptMode KUrlRequester::acceptMode() const
+{
+    return d->fileDialogAcceptMode;
+}
+
 void KUrlRequester::setFilter(const QString &filter)
 {
     d->fileDialogFilter = filter;
@@ -503,15 +512,32 @@ QString KUrlRequester::filter() const
     return d->fileDialogFilter;
 }
 
+void KUrlRequester::setMimeTypeFilters(const QStringList &mimeTypes)
+{
+    d->mimeTypeFilters = mimeTypes;
+
+    if (d->myFileDialog) {
+        d->myFileDialog->setMimeTypeFilters(d->mimeTypeFilters);
+    }
+}
+
+QStringList KUrlRequester::mimeTypeFilters() const
+{
+    return d->mimeTypeFilters;
+}
+
 #ifndef KIOWIDGETS_NO_DEPRECATED
 QFileDialog *KUrlRequester::fileDialog() const
 {
     if (!d->myFileDialog) {
-        QWidget *p = parentWidget();
-        d->myFileDialog = new QFileDialog(p, windowTitle());
-        d->myFileDialog->setNameFilters(d->kToQFilters(d->fileDialogFilter));
+        d->myFileDialog = new QFileDialog(window(), windowTitle());
+        if (!d->mimeTypeFilters.isEmpty()) {
+            d->myFileDialog->setMimeTypeFilters(d->mimeTypeFilters);
+        } else {
+            d->myFileDialog->setNameFilters(d->kToQFilters(d->fileDialogFilter));
+        }
 
-        d->applyFileMode(d->myFileDialog, d->fileDialogMode);
+        d->applyFileMode(d->myFileDialog, d->fileDialogMode, d->fileDialogAcceptMode);
 
         d->myFileDialog->setWindowModality(d->fileDialogModality);
         connect(d->myFileDialog, SIGNAL(accepted()), SLOT(_k_slotFileDialogAccepted()));
@@ -620,7 +646,7 @@ const KEditListWidget::CustomEditor &KUrlRequester::customEditor()
 
 #ifndef NDEBUG
     if (!edit) {
-        qWarning() << "KUrlRequester's lineedit is not a KLineEdit!??\n";
+        qCWarning(KIO_WIDGETS) << "KUrlRequester's lineedit is not a KLineEdit!??\n";
     }
 #endif
 
@@ -630,7 +656,7 @@ const KEditListWidget::CustomEditor &KUrlRequester::customEditor()
 }
 
 KUrlComboRequester::KUrlComboRequester(QWidget *parent)
-    : KUrlRequester(new KComboBox(false), parent), d(0)
+    : KUrlRequester(new KComboBox(false), parent), d(nullptr)
 {
 }
 
